@@ -5,10 +5,11 @@ use strict;
 use warnings;
 use Carp;
 use RRDs;
+use Storable;
 use Data::Dumper;
 use Log::Log4perl qw(:easy);
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
    # Define the mandatory and optional parameters for every method.
 our $OPTIONS = {
@@ -635,7 +636,9 @@ sub error_message {
 #################################################
 sub graph {
 #################################################
-    my($self, @options) = @_;
+    my($self, @params) = @_;
+
+    my @options = @{ Storable::dclone( \@params ) };
 
     my @trailing_options = ();
 
